@@ -2,6 +2,13 @@ from .subreddit import Subreddit, AsyncSubreddit
 from .user import User, AsyncUser
 from .exceptions import RequestError
 
-__version__ = "2.9.0"
+__version__ = "3.0.0"
 __author__ = "MakufonSkifto"
 __license__ = "GNU General Public License v3"
+__all__ = [
+    "Subreddit",
+    "AsyncSubreddit",
+    "User",
+    "AsyncUser",
+    "RequestError"
+]
